@@ -29,8 +29,10 @@ class FlexMock
         should_render_view_after_version_124(template_name)
       elsif rails_version < '2.2'
         should_render_view_after_version_202(template_name)
-      else
+      elsif rails_version < '2.3'
         should_render_view_22x(template_name)    
+      else
+        should_render_view_23x(template_name)    
       end
     end
 
@@ -43,6 +45,7 @@ class FlexMock
       view.should_receive(
         :assigns => {},
         :render_file => true,
+        :render_partial => true,
         :first_render => "dummy_template"
         )
       if template_name
@@ -63,6 +66,7 @@ class FlexMock
       view.should_receive(
         :assigns => {},
         :render_file => true,
+        :render_partial => true,
         :template_format => :dummy_format,
         :view_paths => :dummy_view_paths,
         :pick_template_extension => :dummy_extension
@@ -119,5 +123,22 @@ class FlexMock
       end
       flexmock(ActionView::Base).should_receive(:new).and_return(viewmock)
     end
+
+    # This version of should_render_view will work with versions of
+    # Rails at Version 2.3.x.
+    def should_render_view_23x(template_name)
+      viewmock = flexmock("ViewMock")
+      viewmock.should_receive(
+        :view_paths => viewmock,
+        :render => "RENDERED TEXT")
+      if template_name
+        viewmock.should_receive(:find_template).
+          with(/\/#{template_name}$/, any).
+          and_return(FlexMock.undefined).
+          at_least.once
+      end
+      viewmock.should_ignore_missing
+      flexmock(ActionView::Base).should_receive(:new).and_return(viewmock)
+    end
   end
 end
